@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import inspect
 from typing import TYPE_CHECKING, Type
 
@@ -10,7 +12,7 @@ if TYPE_CHECKING:
 __all__ = ('asyncify_class', 'ignore')
 
 
-def ignore(func: "CallableT") -> "CallableT":
+def ignore(func: CallableT) -> CallableT:
     """|deco|
 
     Ignore a function in a class when using :func:`asyncify.asyncify_class`.
@@ -19,7 +21,7 @@ def ignore(func: "CallableT") -> "CallableT":
     return func
 
 
-def asyncify_class(cls: "TypeT") -> "TypeT":
+def asyncify_class(cls: TypeT) -> TypeT:
     """|deco|
 
     Turn a classes methods into async functions.
@@ -55,7 +57,7 @@ def asyncify_class(cls: "TypeT") -> "TypeT":
         The object passed was not a class.
     """
     if not isinstance(cls, Type):
-        raise TypeError('Expected class, not {!r}'.format(cls))
+        raise TypeError(f'Expected class, got {cls.__class__.__name__!r}')
 
     for name, func in inspect.getmembers(cls):
         if not inspect.isfunction(func) or getattr(func, '_asyncify_ignore', False) or name.startswith('__'):
