@@ -8,6 +8,7 @@ from typing import TYPE_CHECKING, Any, Callable, Coroutine, Generic, Optional, T
 if TYPE_CHECKING:
     from types import FrameType
     from typing_extensions import Self
+    from ._types import Coro
 
 
 __all__ = ('HybridFunction', 'hybrid_function')
@@ -25,20 +26,20 @@ class HybridFunction(Generic[T_sync, T_async]):
         self,
         name: str,
         sync_callback: Callable[..., T_sync],
-        async_callback: Callable[..., Coroutine[Any, Any, T_async]],
+        async_callback: Callable[..., Coro[T_async]],
     ):
         self._name = name
-        if len(inspect.signature(sync_callback).parameters) != len(inspect.signature(async_callback).parameters):
-            raise TypeError('Both function signatures must be the same.')
-
         self.sync_callback = sync_callback
         self.async_callback = async_callback
-        functools.update_wrapper(self, self.sync_callback)
 
         self._instance: Optional[object] = None
 
         self.name_regex = re.compile(rf'\(*{self._name}\)*\s*')
 
+    @property
+    def __name__(self) -> str:
+        return self._name
+
     def __eq__(self, other: object) -> bool:
         return (
             isinstance(other, self.__class__)
@@ -62,12 +63,11 @@ class HybridFunction(Generic[T_sync, T_async]):
         for frame in inspect.getouterframes(current_frame):
             if not frame.code_context:
                 continue
-            print(frame.code_context)
             if self.name_regex.search(frame.code_context[0]):
                 return frame.code_context[0]
         raise RuntimeError('Could not tell if it should call sync or async.')
 
-    def __call__(self, *args: Any, **kwargs: Any) -> Union[T_sync, Coroutine[Any, Any, T_async]]:
+    def __call__(self, *args: Any, **kwargs: Any) -> Union[T_sync, Coro[T_async]]:
         if self._instance:
             args = (self._instance, *args)
 
@@ -81,7 +81,7 @@ class HybridFunction(Generic[T_sync, T_async]):
 
 
 def hybrid_function(
-    name: str, sync_callback: Callable[..., T_sync], async_callback: Callable[..., Coroutine[Any, Any, T_async]]
+    name: str, sync_callback: Callable[..., T_sync], async_callback: Callable[..., Coro[T_async]]
 ) -> HybridFunction[T_sync, T_async]:
     """
     Do multiple things depending on whether it was awaited or not!
