@@ -25,6 +25,8 @@ T = TypeVar('T')
 
 
 class AsyncIterable(Generic[T]):
+    __slots__ = ('iterable', 'iterator', 'before', 'after')
+
     def __init__(
         self,
         iterable: Iterable[T],
@@ -90,6 +92,10 @@ def async_iter(
     .. note::
         `before` and `after` must not take any parameters.
 
+    .. warning::
+        `before` will be called once more than `after` due to not knowing when to stop iterating until after
+        `before` is called.
+
     Example
     ---------
     .. code:: py
@@ -102,7 +108,7 @@ def async_iter(
             sleep = functools.partial(asyncio.sleep, 1)
 
             async for number in async_iter([1, 2, 3], sleep, before=True):
-                print('%d seconds have passed.' % number)
+                print(f'{number} seconds have passed.')
 
     Raises
     -------
